Package: packager
Title: Create, Build and Maintain Packages
Version: 1.15.3
Authors@R: 
    person(given = "Andreas Dominik",
           family = "Cullmann",
           role = c("aut", "cre"),
           email = "fvafrcu@mailbox.org")
Description: Helper functions for package creation, building and
    maintenance. Designed to work with a build system such as 'GNU make' or
    package 'fakemake' to help you to conditionally work through the stages of
    package development (such as spell checking, linting, testing, before
    building and checking a package).
License: BSD_2_clause + file LICENSE
URL: https://gitlab.com/fvafrcu/packager
Depends: R (>= 3.3.0)
Imports: callr, checkmate, codetools, crayon, cyclocomp, desc, fakemake
        (>= 1.10.1), fritools (>= 3.4.0), fs, gert, httr, pkgbuild,
        pkgload, rcmdcheck, remotes, rhub, rprojroot, tinytest, tools,
        whisker, whoami
Suggests: cleanr, covr, devtools, digest, document, knitr, lintr,
        rasciidoc (>= 3.0.1), rmarkdown, roxygen2, RUnit, stats,
        spelling, testthat, usethis, withr
VignetteBuilder: rasciidoc
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-05-24 14:07:14 UTC; qwer
Author: Andreas Dominik Cullmann [aut, cre]
Maintainer: Andreas Dominik Cullmann <fvafrcu@mailbox.org>
Repository: CRAN
Date/Publication: 2025-05-24 14:30:02 UTC
Built: R 4.6.0; ; 2026-04-29 06:03:55 UTC; unix
