# Generated by roxygen2: do not edit by hand

export(add_github_url_to_desc)
export(add_news)
export(as.package)
export(build_manual)
export(check_archive)
export(check_archive_as_cran)
export(check_codetags)
export(check_cyclomatic_complexity)
export(check_news)
export(check_usage)
export(create)
export(eval_from_log)
export(extract_vignette_codes)
export(get_check_status)
export(get_gitlab_log)
export(get_options)
export(get_package_makelist)
export(get_package_version)
export(get_pkg_archive_path)
export(git_add_commit)
export(git_diff)
export(git_tag)
export(grep_log)
export(infect)
export(install_deps)
export(is_r_package)
export(is_version_sufficient)
export(lint_package)
export(mark_lints)
export(print_lints)
export(provide_cran_comments)
export(provide_gitlab_url)
export(provide_make)
export(provide_news_rd)
export(rcmdcheck_and_log)
export(release)
export(remove_lines)
export(set_desc_url)
export(set_options)
export(set_package_info)
export(sort_deps_in_desc)
export(submit)
export(update_deps)
export(use_bsd2clause_license)
export(use_build_ignore)
export(use_dev_version)
export(use_devel_version)
export(use_directory)
export(use_git_check_version_not_tagged)
export(use_git_pre_commit_script)
export(use_template)
