[![pipeline status](https://gitlab.com/{{{ git_user }}}/{{{ package }}}/badges/master/pipeline.svg)](https://gitlab.com/{{{ git_user }}}/{{{ package }}}/-/commits/master)    
[![coverage report](https://gitlab.com/{{{ git_user }}}/{{{ package }}}/badges/master/coverage.svg)](https://gitlab.com/{{{ git_user }}}/{{{ package }}}/-/commits/master)
<!-- 
    [![Build Status](https://travis-ci.org/{{{ git_user }}}/{{{ package }}}.svg?branch=master)](https://travis-ci.org/{{{ git_user }}}/{{{ package }}})
    [![Coverage Status](https://codecov.io/github/{{{ git_user }}}/{{{ package }}}/coverage.svg?branch=master)](https://codecov.io/github/{{{ git_user }}}/{{{ package }}}?branch=master)
-->
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/{{{ package }}})](https://cran.r-project.org/package={{{ package }}})
[![RStudio_downloads_monthly](https://cranlogs.r-pkg.org/badges/{{{ package }}})](https://cran.r-project.org/package={{{ package }}})
[![RStudio_downloads_total](https://cranlogs.r-pkg.org/badges/grand-total/{{{ package }}})](https://cran.r-project.org/package={{{ package }}})

<!-- README.md is generated from README.Rmd. Please edit that file -->

```{r, echo = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.path = "README-"
)
```

# {{{ package }}}
## Introduction
Please read the
[vignette](https://{{{ git_user }}}.gitlab.io/{{{ package }}}/doc/An_Introduction_to_{{{ package }}}.html).
<!-- 
[vignette](https://CRAN.R-project.org/package={{{ package }}}/vignettes/An_Introduction_to_{{{ package }}}.html).

-->

Or, after installation, the help page:
```{r, eval = FALSE}
help("{{{ package }}}-package", package = "{{{ package }}}")
```
```{r, echo = FALSE}
  # insert developement page
  help_file <- file.path("man", "{{{ package }}}-package.Rd")
  captured <- gsub('_\b', '',  capture.output(tools:::Rd2txt(help_file) ))
  cat(captured, sep = "\n")
```

## Installation

You can install {{{ package }}} from gitlab via:

```{r gh-installation, eval = FALSE}
if (! require("remotes")) install.packages("remotes")
remotes::install_gitlab("{{{ git_user }}}/{{{ package }}}")
```


