foobar <- function(x) {
    # this is a lint: this line is way toooooooooooooooooooooooooooooooooooo long! # Exclude Linting
    return(NULL)
}

barfoo <- function(x) {
    # this is not a lint
    return(NULL)
}
